"""Chat channels module with plugin architecture."""

from ragnarbot.channels.base import BaseChannel
from ragnarbot.channels.manager import ChannelManager

__all__ = ["BaseChannel", "ChannelManager"]
